Translations
============

If you want to help to translate this software please join me on Transifex: `transifex.com/projects/p/django-wp-admin/ <https://www.transifex.com/projects/p/django-wp-admin/>`_

Here is a list of available translations.

English
-------

Source (default) language.

German
------

Thanks to `Silasoa <https://www.transifex.com/accounts/profile/Silasoa/>`_

Indonesian
----------

Thanks to `Al Firdaus <https://www.transifex.com/accounts/profile/alfirdaush/>`_

Italian
-------

Thanks to `Giuseppe Pignataro <https://www.transifex.com/accounts/profile/giuseppep/>`_

Polish
------

100% by me (Maciej 'barszcz' Marczewski)

Russian
-------

Thanks to `Eugene MechanisM <https://www.transifex.com/accounts/profile/MechanisM/>`_

